@@ -16,7 +16,7 @@ from typing import Any
 from archinstall.lib.disk.device_handler import device_handler
 from archinstall.lib.disk.fido import Fido2
 from archinstall.lib.disk.utils import get_lsblk_by_mountpoint, get_lsblk_info
-from archinstall.lib.models.device_model import (
+from archinstall.lib.models.device import (
 	DiskEncryption,
 	DiskLayoutConfiguration,
 	EncryptionType,
@@ -30,6 +30,7 @@ from archinstall.lib.models.device_model import (
 	Unit,
 )
 from archinstall.lib.models.packages import Repository
+from archinstall.lib.packages import installed_package
 from archinstall.lib.translationhandler import tr
 from archinstall.tui.curses_menu import Tui
 
@@ -42,7 +43,7 @@ from .luks import Luks2
 from .models.bootloader import Bootloader
 from .models.locale import LocaleConfiguration
 from .models.mirrors import MirrorConfiguration
-from .models.network_configuration import Nic
+from .models.network import Nic
 from .models.users import User
 from .output import debug, error, info, log, logger, warn
 from .pacman import Pacman
@@ -956,6 +957,8 @@ class Installer:
 
 			if bootloader and bootloader == Bootloader.Grub:
 				self.pacman.strap('grub-btrfs')
+				self.pacman.strap('inotify-tools')
+				self._configure_grub_btrfsd()
 				self.enable_service('grub-btrfsd.service')
 
 	def setup_swap(self, kind: str = 'zram') -> None:
@@ -996,6 +999,27 @@ class Installer:
 					return root
 		return None
 
+	def _configure_grub_btrfsd(self) -> None:
+		# See https://github.com/Antynea/grub-btrfs?tab=readme-ov-file#-using-timeshift-with-systemd
+		debug('Configuring grub-btrfsd service')
+
+		# https://www.freedesktop.org/software/systemd/man/latest/systemd.unit.html#id-1.14.3
+		systemd_dir = self.target / 'etc/systemd/system/grub-btrfsd.service.d'
+		systemd_dir.mkdir(parents=True, exist_ok=True)
+
+		override_conf = systemd_dir / 'override.conf'
+
+		config_content = textwrap.dedent(
+			"""
+			[Service]
+			ExecStart=
+			ExecStart=/usr/bin/grub-btrfsd --syslog --timeshift-auto
+			"""
+		)
+
+		override_conf.write_text(config_content)
+		override_conf.chmod(0o644)
+
 	def _get_luks_uuid_from_mapper_dev(self, mapper_dev_path: Path) -> str:
 		lsblk_info = get_lsblk_info(mapper_dev_path, reverse=True, full_dev_path=True)
 
@@ -1172,12 +1196,30 @@ class Installer:
 			bootctl_options.append(f'--esp-path={efi_partition.mountpoint}')
 			bootctl_options.append(f'--boot-path={boot_partition.mountpoint}')
 
-		# Install the boot loader
+		# TODO: This is a temporary workaround to deal with https://github.com/archlinux/archinstall/pull/3396#issuecomment-2996862019
+		# the systemd_version check can be removed once `--variables=BOOL` is merged into systemd.
+		systemd_pkg = installed_package('systemd')
+
+		# keep the version as a str as it can be something like 257.8-2
+		if systemd_pkg is not None:
+			systemd_version = systemd_pkg.version
+		else:
+			systemd_version = '257'  # This works as a safety workaround for this hot-fix
+
 		try:
-			SysCommand(f'arch-chroot {self.target} bootctl {" ".join(bootctl_options)} install')
+			# Force EFI variables since bootctl detects arch-chroot
+			# as a container environemnt since v257 and skips them silently.
+			# https://github.com/systemd/systemd/issues/36174
+			if systemd_version >= '258':
+				SysCommand(f'arch-chroot {self.target} bootctl --variables=yes {" ".join(bootctl_options)} install')
+			else:
+				SysCommand(f'arch-chroot {self.target} bootctl {" ".join(bootctl_options)} install')
 		except SysCallError:
-			# Fallback, try creating the boot loader without touching the EFI variables
-			SysCommand(f'arch-chroot {self.target} bootctl --no-variables {" ".join(bootctl_options)} install')
+			if systemd_version >= '258':
+				# Fallback, try creating the boot loader without touching the EFI variables
+				SysCommand(f'arch-chroot {self.target} bootctl --variables=no {" ".join(bootctl_options)} install')
+			else:
+				SysCommand(f'arch-chroot {self.target} bootctl --no-variables {" ".join(bootctl_options)} install')
 
 		# Loader configuration is stored in ESP/loader:
 		# https://man.archlinux.org/man/loader.conf.5
